# To build the dist package execute:

```hatch build```

# To install with pip
```pip install dist\ioproc-X.X.X-py3-none-any.whl --force-reinstall --no-deps```


# Uploading to pip cheese shop:
(Test pypi repo!)

```python -m twine upload --repository testpypi dist/*```


